@@ -55,7 +55,6 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
             # max_depth_range: list = None,
             # num_leaves_range: list = None,
             # weight_range: list = None,
-            time_cost: bool = True,
             **kwargs
     ):
         """
@@ -73,25 +72,23 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
         DataPretreatment.__init__(
             self, white_set=white_set, drop_col=drop_col, start_num=start_num, nan_rate=nan_rate,
             meaningless_field=meaningless_field, is_structure=is_structure, structure_list=structure_list,
-            form=form, is_extreme=is_extreme, lower=lower, upper=upper, time_cost=time_cost
+            form=form, is_extreme=is_extreme, lower=lower, upper=upper
         )
         FeatureProject.__init__(
             self, is_drop_corr=is_drop_corr, white_set=white_set, label_first=label_first,
             info_first=info_first, corr=corr, is_drop_iv=is_drop_iv, iv_threshold=iv_threshold,
             is_drop_importance=is_drop_importance, importance_threshold=importance_threshold,
-            is_feature_derive=is_feature_derive, derive_n=derive_n, time_cost=time_cost
+            is_feature_derive=is_feature_derive, derive_n=derive_n
         )
         FeatureAnalysis.__init__(
             self, white_set=white_set, is_drop_corr=is_drop_corr, label_first=label_first,
             info_first=info_first, corr=corr, after_pretreatment=after_pretreatment, init_box=init_box,
             final_box=final_box, importance_rate=importance_rate, top_importance_k=top_importance_k,
-            time_cost=time_cost
         )
         ModelBuild.__init__(
             self, baseline=baseline, max_depth=max_depth, weight=weight, lgb_params=lgb_params,
             xgb_params=xgb_params, early_stopping=early_stopping, verbose=verbose, epoch=epoch,
             is_evaluate=is_evaluate, evaluate_func=evaluate_func, is_adjust_parameter=is_adjust_parameter,
-            time_cost=time_cost
         )
         self.is_analysis = is_analysis
         self.field_dict = field_dict
@@ -206,7 +203,7 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
             white_set=self.white_set, field_dict=self.field_dict, drop_col=self.drop_col, start_num=self.start_num,
             nan_rate=self.nan_rate, meaningless_field=self.meaningless_field, is_structure=self.is_structure,
             structure_list=self.structure_list, form=self.form, is_extreme=self.is_extreme, lower=self.lower,
-            upper=self.upper, time_cost=self.time_cost)
+            upper=self.upper)
         pretreatment_df = pretreatment.fit(data, label)
         col_dict = pretreatment.col_dict
         convert_dict = pretreatment.convert_dict
@@ -219,7 +216,7 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
                 is_drop_corr=self.is_drop_corr, label_first=self.label_first, info_first=self.info_first,
                 corr=self.corr, after_pretreatment=self.after_pretreatment, init_box=self.init_box,
                 final_box=self.final_box, importance_rate=self.importance_rate,
-                top_importance_k=self.top_importance_k, time_cost=self.time_cost
+                top_importance_k=self.top_importance_k
             )
             analysis.fit(pretreatment_df, label, original_data=data)
         print('==========\n 特征工程')
@@ -228,7 +225,7 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
             label_first=self.label_first, info_first=self.info_first, corr=self.corr, is_drop_iv=self.is_drop_iv,
             iv_threshold=self.iv_threshold, is_drop_importance=self.is_drop_importance,
             importance_threshold=self.importance_threshold, is_feature_derive=self.is_feature_derive,
-            derive_n=self.derive_n, time_cost=self.time_cost
+            derive_n=self.derive_n
         )
         project_df = project.fit(pretreatment_df, label)
         self.train_project_df = project_df
@@ -238,7 +235,7 @@ class AutoModel(DataPretreatment, FeatureProject, FeatureAnalysis, ModelBuild):
             baseline=self.baseline, field_dict=self.field_dict, max_depth=self.max_depth, weight=self.weight,
             lgb_params=self.lgb_params, xgb_params=self.xgb_params, early_stopping=self.early_stopping,
             verbose=self.verbose, epoch=self.epoch, is_evaluate=self.is_evaluate, evaluate_func=self.evaluate_func,
-            is_adjust_parameter=self.is_adjust_parameter, time_cost=self.time_cost
+            is_adjust_parameter=self.is_adjust_parameter
         )
         model, importance = model_build.fit(project_df, label)
         self.model_build = model_build
