@@ -3,9 +3,8 @@ import re
 import copy
 import math
 import pandas as pd
-import time
 from pprint import pprint
-from.function import is_number, col_is_number, keep_drop_judge
+from.function import print_time, is_number, col_is_number, keep_drop_judge
 
 # 最高10类数量占比
 top10_rate = 0.9
@@ -151,7 +150,6 @@ class DataPretreatment:
             is_extreme: bool = True,
             lower: float = 0.01,
             upper: float = 0.99,
-            time_cost: bool = True,
     ):
         """
         Parameters
@@ -183,8 +181,6 @@ class DataPretreatment:
             下限
         upper: float
             上限
-        time_cost: bool
-            是否显示耗时
         """
         if form not in {'sum', 'separate', 'have'}:
             raise ValueError('请在 sum, separate, have中选择一个')
@@ -206,7 +202,6 @@ class DataPretreatment:
             'num_cla_col': [],
             'to_cla_col': []
         }
-        self.time_cost = time_cost
         self.structure_copy = copy.deepcopy(self.structure_list)
         self.nan_pd = None
         self.convert_dict = None
@@ -275,17 +270,20 @@ class DataPretreatment:
         """
         data = copy.deepcopy(data)
         data.drop(self.col_dict['drop_col'], axis=1, inplace=True)
-        print('类型字段转数值')
+        print('----------\n 类型字段转数值')
         data = self.str_to_number(data, '', convert_dict=self.convert_dict)
         data.drop(self.structure_copy, axis=1, inplace=True)
-        print('填补缺失值')
+        print('----------\n 填补缺失值')
         data = self.deal_with_nan(data, '', fill_dict=self.fill_dict)
         data = text_deal_with_nan(data, self.col_dict)
+        print('----------\n 将obj字段转化为数值型')
+        data = self.type_conversion(data)
         if self.is_extreme:
-            print('处理异常值')
+            print('----------\n 处理异常值')
             data = self.deal_with_extreme(data)
         return data
 
+    @print_time
     def nan_statistic(
             self,
             data: pd.DataFrame,
@@ -293,7 +291,6 @@ class DataPretreatment:
         """
         统计缺失值总和及占比
         """
-        start = time.time()
         n = data.shape[0]
         nan_pd = data.isnull().sum().to_frame().reset_index()
         nan_pd.columns = ['col', 'nan_count']
@@ -322,11 +319,9 @@ class DataPretreatment:
             print('因过多的缺失值而被舍弃的字段:')
             pprint(drop_df)
         self.col_dict['drop_col'].extend(drop)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return nan_pd, drop
 
+    @print_time
     def identify_type(
             self,
             data: pd.DataFrame,
@@ -339,7 +334,6 @@ class DataPretreatment:
         num_cla_col : 数值型类别字段
         to_cla_col : 类别字段，可做编码或one-hot
         """
-        start = time.time()
         meaningless_drop = []
         meaningless_drop_name = []
         low_kind_drop = []
@@ -436,11 +430,9 @@ class DataPretreatment:
         drop_col.extend(low_kind_drop)
         drop_col.extend(multi_kind_drop)
         self.col_dict['drop_col'].extend(drop_col)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return self.col_dict, drop_col
 
+    @print_time
     def str_to_number(
             self,
             data: pd.DataFrame,
@@ -456,7 +448,6 @@ class DataPretreatment:
         convert_dict: dict
             自定义映射关系，在测试集上使用
         """
-        start = time.time()
         if col_dict is None and convert_dict is None:
             col_dict, _ = self.identify_type(data, label)
         data = copy.deepcopy(data)
@@ -492,11 +483,9 @@ class DataPretreatment:
                 convert_dict[col] = type_dict
             data[col] = data[col].map(lambda x: type_dict[x] if x in type_dict else 31)
         self.convert_dict = convert_dict
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return convert_dict, data
 
+    @print_time
     def deal_with_nan(
             self,
             data: pd.DataFrame,
@@ -516,7 +505,6 @@ class DataPretreatment:
                 nan_pd, _ = self.nan_statistic(data)
             if col_dict is None:
                 col_dict, _ = self.identify_type(data, label)
-        start = time.time()
         if fill_dict is not None:
             for k, v in fill_dict.items():
                 if k == 'others':
@@ -543,17 +531,14 @@ class DataPretreatment:
                 fill_dict[-1].append(col)
                 data[col].fillna(-1, inplace=True)
         self.fill_dict = fill_dict
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return fill_dict, data
 
+    @print_time
     def deal_with_extreme(
             self,
             data: pd.DataFrame,
             label: str = None
     ):
-        start = time.time()
         data = copy.deepcopy(data)
         cols = data.columns
         if label is not None:
@@ -562,11 +547,9 @@ class DataPretreatment:
             a = data[col].quantile(self.lower)
             b = data[col].quantile(self.upper)
             data[col] = data[col].map(lambda x: b if x > b else a if x < a else x)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return data
 
+    @print_time
     def type_conversion(
             self,
             data: pd.DataFrame,
@@ -574,12 +557,12 @@ class DataPretreatment:
         """
         将obj类型字段转化为数值
         """
-        start = time.time()
         obj_col = data.select_dtypes(include=['object']).columns
         for col in obj_col:
             try:
                 data[col] = data[col].astype(float)
             except (ValueError, TypeError):
+                print('特殊转换的字段:', col)
                 unique_kind = data[col].unique()
                 type_dict = {}
                 obj_list = []
@@ -599,9 +582,6 @@ class DataPretreatment:
                     max_num += 1
                 self.convert_dict[col] = type_dict
                 data[col] = data[col].map(type_dict)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return data
 
     def reset_atr(self):
