@@ -1,12 +1,11 @@
 import copy
-import time
 import pandas as pd
 import numpy as np
 from pprint import pprint
 import scipy.stats as st
 from sklearn.ensemble import RandomForestClassifier
 from .data_pretreatment import col_is_number
-from .function import divide
+from .function import print_time, divide
 
 
 # 最高10类数量占比
@@ -199,7 +198,6 @@ class FeatureAnalysis:
             final_box: int = 7,
             importance_rate: float = None,
             top_importance_k: int = 20,
-            time_cost: bool = True
     ):
         """
         Parameters
@@ -226,8 +224,6 @@ class FeatureAnalysis:
             取重要性总占比超过importance_rate的字段
         top_importance_k: int
             取重要性前k个字段
-        time_cost: bool
-            是否显示耗时
         """
         self.col_dict = col_dict
         if col_dict is not None:
@@ -255,7 +251,6 @@ class FeatureAnalysis:
         self.corr_dict = None
         self.corr_with_label = None
         self.top_k_dict = {}
-        self.time_cost = time_cost
 
     def fit(
             self,
@@ -307,7 +302,6 @@ class FeatureAnalysis:
             data: pd.DataFrame,
             label: str,
     ):
-        start = time.time()
         self.corr_pd = data.drop(label, axis=1).corr()
         corr_dict = {}
         for i, col in enumerate(data.columns.drop(label)):
@@ -318,9 +312,6 @@ class FeatureAnalysis:
                     else:
                         corr_dict[col] = [data.columns[j]]
         self.corr_dict = corr_dict
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return self.corr_pd, self.corr_dict
 
     def col_label_corr(
@@ -331,6 +322,7 @@ class FeatureAnalysis:
         self.corr_with_label = data.corrwith(data[label])
         return self.corr_with_label
 
+    @print_time
     def drop_corr_col(
             self,
             data: pd.DataFrame,
@@ -477,12 +469,12 @@ class FeatureAnalysis:
         print('iv值:', iv)
         return bins_df, iv
 
+    @print_time
     def feature_importance(
             self,
             data: pd.DataFrame,
             label: str
     ):
-        start = time.time()
         x = data.drop(label, axis=1)
         weight = round(data[data[label] == 0][label].count() / data[data[label] == 1][label].count(), 3)
         forest = RandomForestClassifier(n_estimators=100, max_depth=8, n_jobs=-1,
@@ -502,9 +494,6 @@ class FeatureAnalysis:
         else:
             for index in indices[:self.top_importance_k]:
                 top_k_dict[field[index]] = importance[index]
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return top_k_dict
 
     def auto_bin(
