@@ -1,5 +1,4 @@
 
-import time
 import numpy as np
 from sklearn.model_selection import train_test_split
 from pprint import pprint
@@ -8,10 +7,7 @@ from sklearn.ensemble import RandomForestClassifier
 from sklearn.metrics import classification_report, accuracy_score, confusion_matrix, f1_score
 import lightgbm as lgb
 import xgboost as xgb
-try:
-    from sklearn.externals import joblib
-except ImportError:
-    import joblib
+from.function import print_time
 
 
 version = lgb.__version__
@@ -241,7 +237,6 @@ class ModelBuild:
             is_evaluate: bool = False,
             evaluate_func: function = None,
             is_adjust_parameter: bool = False,
-            time_cost: bool = True,
             **kwargs
     ):
         """
@@ -269,8 +264,6 @@ class ModelBuild:
             采用评价函数的具体函数
         is_adjust_parameter: bool
             是否自动调参
-        time_cost:
-            是否显示耗时
         kwargs:
             train_test_split内的参数
         """
@@ -286,7 +279,6 @@ class ModelBuild:
         self.is_evaluate = is_evaluate
         self.evaluate_func = evaluate_func
         self.is_adjust_parameter = is_adjust_parameter
-        self.time_cost = time_cost
         if 'random_state' not in kwargs:
             kwargs['random_state'] = 1
         for k, v in kwargs.items():
@@ -379,6 +371,7 @@ class ModelBuild:
             data.drop(label, axis=1, inplace=False), data[label], **self.kwargs)
         return x_train, x_val, y_train, y_val
 
+    @print_time
     def rfc_fit(
         self,
         data: pd.DataFrame,
@@ -394,12 +387,12 @@ class ModelBuild:
             x_train, x_val, y_train, y_val, max_depth, weight, self.field_dict)
         return model, feature_importance
 
+    @print_time
     def rfc_auto_adjust_parameter(
             self,
             data: pd.DataFrame,
             label: str
     ):
-        start = time.time()
         x_train, x_val, y_train, y_val = self.train_test_split(data, label)
         balance, fitting = rfc_cal_fitting(x_train, x_val, y_train, y_val, 1, 1)
         print('----------\n max_depth: %d, weight: %s, 召回-精度: %s, 验证f1-训练f1: %s' %
@@ -408,11 +401,9 @@ class ModelBuild:
         print('最终max_depth: %s, 最终weight: %s' % (max_depth, weight))
         model, feature_importance = rfc_model_importance(
             x_train, x_val, y_train, y_val, max_depth, weight, self.field_dict)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return model, feature_importance
 
+    @print_time
     def lgb_fit(
             self,
             data: pd.DataFrame,
@@ -550,12 +541,12 @@ class ModelBuild:
             return self.lgb_adjust_parameter(x_train, x_val, y_train, y_val, num_leaves, weight, balance, fitting,
                                              parameter_dict)
 
+    @print_time
     def lgb_auto_adjust_parameter(
             self,
             data: pd.DataFrame,
             label: str
     ):
-        start = time.time()
         x_train, x_val, y_train, y_val = self.train_test_split(data, label)
         balance, fitting = self.lgb_cal_fitting(x_train, x_val, y_train, y_val, 10, 1)
         print('----------\n num_leaves: %d, weight: %s, 召回-精度: %s, 验证f1-训练f1: %s' %
@@ -572,11 +563,9 @@ class ModelBuild:
         pre_train = np.where(pre_train >= 0.5, 1, 0)
         pre_val = np.where(pre_val >= 0.5, 1, 0)
         output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return model, importance
 
+    @print_time
     def xgb_fit(
         self,
         data: pd.DataFrame,
@@ -706,12 +695,12 @@ class ModelBuild:
             return self.xgb_adjust_parameter(x_train, x_val, y_train, y_val, max_depth, weight,
                                              balance, fitting, parameter_dict)
 
+    @print_time
     def xgb_auto_adjust_parameter(
             self,
             data: pd.DataFrame,
             label: str
     ):
-        start = time.time()
         x_train, x_val, y_train, y_val = self.train_test_split(data, label)
         balance, fitting = self.xgb_cal_fitting(x_train, x_val, y_train, y_val, 1, 1)
         print('----------\n max_depth: %d, weight: %s, 召回-精度: %s, 验证f1-训练f1: %s' %
@@ -729,9 +718,6 @@ class ModelBuild:
         pre_train = np.where(pre_train >= 0.5, 1, 0)
         pre_val = np.where(pre_val >= 0.5, 1, 0)
         output(importance, y_train, y_val, pre_train, pre_val, self.field_dict)
-        end = time.time()
-        if self.time_cost:
-            print('耗时:', round(end - start, 4))
         return model, importance
 
     def reset_atr(self):
